/*
 *
 * Copyright (c) 2000 - 2012 Samsung Electronics Co., Ltd All Rights Reserved
 * This file is part of drm-service
 * Written by Hakjoo Ko <hakjoo.ko@samsung.com>
 * 
 * PROPRIETARY/CONFIDENTIAL
 *
 * This software is the confidential and proprietary information of
 * SAMSUNG ELECTRONICS ("Confidential Information"). You shall not 
 * disclose such Confidential Information and shall use it only in 
 * accordance with the terms of the license agreement you entered 
 * into with SAMSUNG ELECTRONICS.
 * SAMSUNG make no representations or warranties about the suitability
 * of the software, either express or implied, including but not limited
 * to the implied warranties of merchantability, fitness for a particular 
 * purpose, or non-infringement. SAMSUNG shall not be liable for any 
 * damages suffered by licensee as a result of using, modifying or 
 * distributing this software or its derivatives.
 *
 */

#ifndef __DRM_SERVICE_H__
#define __DRM_SERVICE_H__

#ifdef __cplusplus
extern "C" {
#endif

#include "drm-service-types.h"

/*===========================================================================

								DRM Unified service layer API

===========================================================================*/

/**
* @internal
* @defgroup DRM-SERVICE drm-service
* @{
*/
 /**
 *  An application can check that a file is DRM file(both OMA DRM and WMDRM)
 *
 * @param[in]	pFilePath	   Specifies the pointer points a DRM file path.
 * @return		This function returns DRM_TRUE on success or DRM_FALSE on failure.
 * @remarks     According to DRM type, the checking method is different. It is the following.
 *                    In case of WMDRM, this function checks file extension first, and then checks that it has kid value in its header.
 *                    In another case, OMA DRM, this function checks only file extension.
 * @see
 * @since          1.0
 */
DRM_BOOL drm_svc_is_drm_file(const char *filePath);
/**
	*@}
*//* Doxygen : defgroup */

/**
* @internal
* @addtogroup DRM-SERVICE
* @{
*/

/**
 *  An application can get DRM file type of the file that is specified in filePath
 *
 * @param[in] filePath	   Specifies the pointer points a DRM file path.
 * @return		This function returns DRM_FILE_TYPE_OMA or DRM_FILE_TYPE_DIVX or DRM_FILE_TYPE_PLAYREADY on success or DRM_NONE on failure.
 * @remarks     According to DRM type, the checking method is different. It is the following.
 *                    In case of WMDRM, this function checks file extension first, and then checks that it has kid value in its header.
 *                    In another case, OMA DRM, this function checks only file extension.
 * @see
 * @since          Common API ver 1.0
 */
DRM_FILE_TYPE drm_svc_get_drm_type(const char *filePath);

/**
 * An application can get a file description from DRM_FILE_HANDLE.
 *
 * @param[in]  hFile       Handle that identifies DRM file.
 * @param[out] fd          The value of file description.
 * @return		This function returns DRM_TRUE on success or DRM_FALSE on failure.
 * @remarks	   The value of fd is not file description.
 * @see 	      drm_svc_is_drm_file_handle, drm_svc_convert_fd_to_handle.
 * @since          1.0
 */
DRM_BOOL drm_svc_convert_handle_to_fd(DRM_FILE_HANDLE hFile, int *fd);

/**
 * An application can get DRM_FILE_HANDLE from a file description.
 *
 * @param[in]  fd          The value of file description.
 * @param[out] hFile       Handle that identifies DRM file.
 * @return		This function returns DRM_TRUE on success or DRM_FALSE on failure.
 * @remarks	   The value of fd is not file description.
 * @see 	      drm_svc_is_drm_file_handle, drm_svc_convert_handle_to_fd.
 * @since          1.0
 */
DRM_BOOL drm_svc_convert_fd_to_handle(int fd, DRM_FILE_HANDLE *hFile);

/**
 *  An application can check if a file handle is a DRM file handle.(Both OMA DRM and WMDRM)
 *
 * @param[out] hFile       Handle that identifies DRM file.
 * @return		This function returns DRM_TRUE on success or DRM_FALSE on failure.
 * @remarks
 * @see 	      drm_svc_open_file, drm_svc_close_file
 * @since          1.0
 */
DRM_BOOL drm_svc_is_drm_file_handle(DRM_FILE_HANDLE hFile);

/**
 * An application can get DRM file handle that is used for reading decrypted data.
 * In case of OMA DRM file, if DRM file has invalid RO, this function returns fail.
 * In another case, WMDRM file, only if DRM file is able to be opened, this function returns success.
 *
 * @param[in]	filePath	   Specifies the pointer points a DRM file path.
 * @param[in]  permType    Enumeration type of permission.
 * @param[out] hFile       Handle that identifies DRM file.
 * @return		This function returns DRM_RESULT_SUCCESS on success or other values on failure.
 * @remarks
 * @see
 * @since          1.0
 */
DRM_RESULT drm_svc_open_file(const char *filePath,
				     DRM_PERMISSION_TYPE permType,
				     DRM_FILE_HANDLE *hFile);

/**
 * An application can read the decrypted data from a OMA DRM file.
 *
 * @param[in]	hFile	      Specifies the handle that identifies DRM file.
 * @param[in]  buffer      Specifies the pointer points a buffer for decrypted data.
 * @param[in]  size        The size of buffer.
 * @param[out] readSize    Actual read size.
 * @return		This function returns DRM_RESULT_SUCCESS on success or other values on failure.
 * @remarks
 * @see 	      drm_svc_open_file, drm_svc_seek_file, drm_svc_tell_file, drm_svc_close_file
 * @since          1.0
 */
DRM_RESULT drm_svc_read_file(DRM_FILE_HANDLE hFile,
				     void *buffer,
				     unsigned int size, unsigned int *readSize);

/**
 *  An application can move DRM file pointer.
 *
 * @param[in]	hFile 	   Specifies the handle that identifies DRM file.
 * @param[in]  offset      The offset to move.
 * @param[in]  mode        The mode to decide start position.
 * @return		This function returns DRM_RESULT_SUCCESS on success or other values on failure.
 * @remarks
 * @see 	      drm_svc_open_file, drm_svc_seek_file, drm_svc_tell_file, drm_svc_close_file
 * @since          1.0
 */
DRM_RESULT drm_svc_seek_file(DRM_FILE_HANDLE hFile,
				     int offset, DRM_FILE_SEEK_MODE mode);

/**
 * An application can get DRM file pointer.
 *
 * @param[in]	hFile	      Specifies the handle that identifies DRM file.
 * @return		This function returns DRM_RESULT_SUCCESS on success or other values on failure.
 * @remarks
 * @see 	      drm_svc_open_file, drm_svc_seek_file, drm_svc_close_file
 * @since          1.0
 */
unsigned int drm_svc_tell_file(DRM_FILE_HANDLE hFile);

/**
 * An application can close DRM file.
 *
 * @param[in]	hFile	      Specifies the handle that identifies DRM file.
 * @return		This function returns DRM_RESULT_SUCCESS on success or other values on failure.
 * @remarks
 * @see 	      drm_svc_open_file, drm_svc_seek_file, drm_svc_tell_file
 * @since          1.0
 */
DRM_RESULT drm_svc_close_file(DRM_FILE_HANDLE hFile);

/**
 * An application can get DRM file attribute.
 *
 * @param[in]	filePath	      Specifies the pointer points a DRM file path.
 * @param[out] fileattribute  Specifies the pointer points a DRM file attribute.
 *                            Application allocate a memory for
 * @return		This function returns DRM_RESULT_SUCCESS on success or other values on failure.
 * @remarks
 * @see 	      drm_svc_open_file, drm_svc_seek_file, drm_svc_tell_file
 * @since          1.0
 */
DRM_RESULT drm_svc_get_fileattribute(const char *filePath,
					     drm_file_attribute_t *fileattribute);

/**
 *  An application can get consume handle that contains a information about RO
 *
 * @param[in]	pFilePath	   Specifies the pointer points a DRM file path.
 * @param[in]  permType       Enumeration type of permission.
 * @param[out] hRightsConsume Specifies the pointer points a consuming handle.
 * @return		This function returns DRM_RESULT_SUCCESS on success or other values on failure.
 * @remarks
 * @see 	      drm_svc_start_consumption, drm_svc_pause_consumption, drm_svc_stop_consumption, drm_svc_close_consumption
 * @since          1.0
 */
DRM_RESULT drm_svc_open_consumption(const char *filePath,
					    DRM_PERMISSION_TYPE permType,
					    DRM_RIGHTS_CONSUME_HANDLE *hRightsConsume);

/**
 * An application can start consuming RO .
 * An application must call this function when player starts redering a DRM file.
 *
 * @param[in]	hRightsConsume	   Specifies the pointer points a consuming handle.
 * @return		This function returns DRM_RESULT_SUCCESS on success or other values on failure.
 * @remarks
 * @see 	      drm_svc_open_consumption, drm_svc_pause_consumption, drm_svc_stop_consumption, drm_svc_close_consumption
 * @since          1.0
 */
DRM_RESULT drm_svc_start_consumption(DRM_RIGHTS_CONSUME_HANDLE hRightsConsume);

/**
 * An application can pause consuming RO.
 * An application must call this function when player pauses redering a DRM file.
 *
 * @param[in]	hRightsConsume	   Specifies the pointer points a consuming handle.
 * @return		This function returns DRM_RESULT_SUCCESS on success or other values on failure.
 * @remarks
 * @see 	      drm_svc_open_consumption, drm_svc_start_consumption, drm_svc_stop_consumption, drm_svc_close_consumption
 * @since          1.0
 */
DRM_RESULT drm_svc_pause_consumption(DRM_RIGHTS_CONSUME_HANDLE hRightsConsume);

/**
 * An application can stop consuming RO.
 * An application must call this function when player finishes redering a DRM file.
 * In case of WMDRM file, consumption occurs in this function actually.
 *
 * @param[in]	hRightsConsume	   Specifies the pointer points a consuming handle.
 * @return		This function returns DRM_RESULT_SUCCESS on success or other values on failure.
 * @remarks
 * @see 	      drm_svc_open_consumption, drm_svc_start_consumption, drm_svc_pause_consumption, drm_svc_close_consumption
 * @since          1.0
 */
DRM_RESULT drm_svc_stop_consumption(DRM_RIGHTS_CONSUME_HANDLE hRightsConsume);

/**
 * An application can release resource that is allocated for consumption.
 *
 * @param[in]	hRightsConsume	   Specifies the pointer points a consuming handle.
 * @return		This function returns DRM_RESULT_SUCCESS on success or other values on failure.
 * @remarks
 * @see 	      drm_svc_open_consumption, drm_svc_start_consumption, drm_svc_pause_consumption, drm_svc_stop_consumption
 * @since          1.0
 */
DRM_RESULT drm_svc_close_consumption(DRM_RIGHTS_CONSUME_HANDLE *hRightsConsume);

/**
 * An application can notify to DRM engine whether user has changed a local time.
 *
 * @param[in]	before	   The local time before modification.
 * @param[in]  after       The local time after modification.
 * @return		This function returns DRM_RESULT_SUCCESS on success or other values on failure.
 * @remarks
 * @see 	      drm_svc_open_ro_iterator, drm_svc_close_ro_iterator
 * @since          1.0
 */
DRM_RESULT drm_svc_update_secure_clock(unsigned int before,
					       unsigned int after);

/**
 * An application should call this function for DRM system when maset reset.
 * DRM library initialize all information like a database and secure time, and install
 *    CMLA Certification Package.
 *
 * In the case of OMA DRM, this API performs following activities.
 * 	- Drop and Create all tables
 *	- Reset alarm features
 *     - Clear DRM specific cache (which is shared among processes)
 *	- Install certificate pack
 *	- Disable DRM secure clock
 *	- Reset the UCwhitelist info to include info specific to default user-consent whitelist
 *	- Create DRM specific directories (needed for DRM processing).

 * @return
 * @remarks
 * @see 	      drm_svc_verify_encrypted_cert
 * @since          1.0
 */
void drm_svc_master_reset(void);

/**
 * An application can check verification of installed CMLA Certification Package.
 *
 *
 * @return		This function returns DRM_TRUE on success or other values on failure.
 * @remarks
 * @see 	      drm_svc_master_reset
 * @since          1.0
 */
DRM_BOOL drm_svc_verify_encrypted_cert(void);

/**
 * An application can check that a DRM file has valid RO.
 *
 * @param[in]	pFilePath	   Specifies the pointer points a DRM file path.
 * @param[in]	permType	      Enumeration type of permission.
 * @return		This function returns DRM_RESULT_SUCCESS on success or other values on failure.
 * @remarks
 * @see
 * @since          1.0
 */
DRM_RESULT drm_svc_has_valid_ro(const char *filePath,
					DRM_PERMISSION_TYPE permType);

/**
 * An application can get a information(mime type and content ID) of a DRM file.
 *
 * @param[in]	filePath	   Specifies the pointer points a DRM file path.
 * @param[out] contentInfo Specifies the pointer points a information of a DRM file.
 *                         Application should allocate a memory.
 * @return		This function returns DRM_RESULT_SUCCESS on success or other values on failure.
 * @remarks
 * @see
 * @since          1.0
 */
DRM_RESULT drm_svc_get_content_info(const char *filePath,
					    drm_content_info_t *contentInfo);

/*---------------------------------------------------------------------------
					DRM CONTENT INFORMATION & SEARCH
---------------------------------------------------------------------------*/
/**
 * An application can get a information(version and delivery method) of a DRM file.
 *
 * @param[in]	filePath	   Specifies the pointer points a DRM file path.
 * @param[out] fileInfo    Specifies the pointer points a information of a DRM file.
 *                         Application should allocate a memory.
 * @return		This function returns DRM_RESULT_SUCCESS on success or other values on failure.
 * @remarks
 * @see
 * @since          1.0
 */
DRM_RESULT drm_svc_get_dcf_file_info(const char *filePath,
					     drm_dcf_info_t *fileInfo);

/**
 * An application can register a DRM file.
 * If a DRM file is multipart-DCF, DRM library will register all media object in the file implicitly.
 * If a DRM file contains RO, DRM library will register all RO in the file implicitly.
 *
 * @param[in]	filePath	   Specifies the pointer points a DRM file path.
 * @return		This function returns DRM_RESULT_SUCCESS on success or other values on failure.
 * @remarks
 * @see 	      drm_svc_unregister_file
 * @since          1.0
 */
DRM_RESULT drm_svc_register_file(const char *pFilePath);

/**
 * An application can unregister a DRM file when application remove a DRM file.
 * This function don't check that a DRM file is exist. Only this function delete information of database.
 * So, if application try to unregister a DRM file that had not been registered before, this function will return success.
 * Because unregistered file doesn't need to unregister.
 *
 * @param[in]	filePath	      Specifies the pointer points a DRM file path.
 * @param[in]  removeRights   A boolean value whether unregister RO.
 *                            If this value is DRM_TRUE, library will unregister RO, too.
 * @return		This function returns DRM_RESULT_SUCCESS on success or other values on failure.
 * @remarks
 * @see 	      drm_svc_register_file
 * @since          1.0
 */
DRM_RESULT drm_svc_unregister_file(const char *pFilePath,
					   DRM_BOOL removeRights);

/**
 * An application can unregister all OMA DRM files after mass storage mode is disconnected.
 * @return                         This function returns DRM_RESULT_SUCCESS on success or other values on failure.
 * @remarks                      This API can be called after disconnection from mass storage mode.
 *					     After successful call of this API, application need to register contents again by calling drm_svc_register_file
 * @see                             drm_svc_unregister_file
 */
DRM_RESULT drm_svc_unregister_all_contents(void);

/*===========================================================================

								OMADRM service layer API

===========================================================================*/

/**
 * An application can create all DRM related DB tables.
 *
 * @return		This function returns DRM_TRUE on success or DRM_FALSE on failure.
 */
DRM_BOOL drm_svc_create_init_db(void);

/*
 * An application should call this function for DRM system to initialize all information like  secure time, and install
 * CMLA Certification Package. This function does not initialise Database and alarm.
 * Currently it is meant during first bootup after flashing binaries
 *
 * @return		  DRM_TRUE in the case of success else DRM_FALSE
 * @remarks		  DRM DB table must be created before using this API
 * @see 	      drm_svc_create_init_db
 * @since          1.0
*/
DRM_BOOL drm_svc_master_reset_op(void);

/**
 * An application can subscribe event for DRM.It is specific to SPL2 ONLY and internally uses DBUS / EDBUS
 * @param[in]		data	      pointer to drm_event_subscribe_info
 * @return	void
 * @remarks
 * @see		drm_svc_publish_event
 * @since      	1.0
 */
void drm_svc_subscribe_event_dbus(drm_event_subscribe_info *data);

/**
 * An application can reinstall CMLA CERT for DRM
 * @return	DRM_BOOL
 * @remarks
 * @see		drm_svc_verify_encrypted_cert, drm_svc_master_reset, drm_svc_subscribe_event
 * @since      	1.0
 */
DRM_BOOL drm_svc_reinstall_cert(void);

/*---------------------------------------------------------------------------
							DRM NET Manager
---------------------------------------------------------------------------*/
/**
 * An application can initialize the queue for ROAP PDU.
 * An application should call this function when application start.
 * @return
 * @remarks
 * @see 	      drm_svc_submit_roap_message, drm_svc_submit_roap_user_consent, drm_svc_cancel_roap
 * @since      1.0
 */
void drm_svc_init_roap_queue(void);

/**
 * An application can process a ROAP to get Rights.
 * Receives ROAP Trigger or ROAP PDU to perform the requested protocol.
 * Registration, Join Domain, and RO Acquisition can be performed by
 *registering ROAP Trigger received from browser or 1-Pass ROAP PDU received from OTA Push
 *to this function. Protocol's progress can be referenced by designating the Callback function
 *when calling this function.
 *Registering Application Data makes it possible to use it at the Callback function.
 * @param[in]	buffer 	      buffer that contains Trigger of PDU data.
 * @param[in]	size 	         buffer size
 * @param[in]	pRoapNotiCB 	Specifies the pointer points a structure that composed callback functions.
 * @param[in]	initiator      Application type running ROAP.
 * @param[in]  appSessionData Specifies the pointer points a application's session data.
 *                               If ROAP is running in multiple processes, application can use this parameter
 *                               to identify processes and callback function.
 *                               Reference the structure, "drm_appsession_datatype_t".
 * @return		This function returns DRM_RESULT_SUCCESS on success or other values on failure.
 * @remarks
 * @see 	      drm_svc_init_roap_queue, drm_svc_submit_roap_user_consent, drm_svc_cancel_roap
 * @since      1.0
 */
DRM_RESULT drm_svc_submit_roap_message(unsigned char *buffer,
					       unsigned int size,
					       drm_roap_notification_cb_t *pRoapNotiCB,
					       DRM_ROAP_INITIATOR iniiator,
					       drm_appsession_datatype_t *appSessionData);

/**
 * An application notifies DRM engine of results from user consent request.
 * When user consent becomes needed while ROAP is in progress, the caller is informed through Callback.
 * This function notifies DRM engine of the user consent result delivered through Callback.
 * Because ROAP session goes in standby when user consent is needed,
 *it must be reinitiated using this function after receiving user consent Callback.
 * So, "drm_roap_consent_cb" is called, application should call this function and notify a result of user consent to DRM engine.
 * @param[in]	pConsentInfo 	      A result of user consent.
 * @param[in]	agentData      Specifies the pointer points a ROAP session information that is used by DRM engine.
 *                            Must deliver agentData received through Callback completely intact.
 * @return		This function returns DRM_RESULT_SUCCESS on success or other values on failure.
 * @remarks
 * @see 	      drm_svc_init_roap_queue, drm_svc_submit_roap_message, drm_svc_cancel_roap
 * @since      1.0
 */
DRM_RESULT drm_svc_submit_roap_user_consent
	    (const drm_uc_info_t *const pConsentInfo, void *agentData);

 /**
 * An application can cancel process of ROAP.
 *
 *
 * @param[in]	appSessinData	Specifies the pointer points to an application session data
 *                            that is used as parameter of function, "drm_svc_submit_roap_message".
 * @return	   This function returns DRM_TRUE on success or DRM_FALSE on failure.
 * @remarks
 * @see 	      drm_svc_submit_roap_message, drm_svc_submit_roap_user_consent
 * @since      1.0
 */
DRM_BOOL drm_svc_http_user_cancel(void *appSessionData);

/*---------------------------------------------------------------------------
							DRM RIGHTS
---------------------------------------------------------------------------*/
/**
 * An application can create the RO's Iterator of DRM file.
 *
 * @param[in]	pFilePath	   Specifies the pointer points a DRM file path.
 * @param[out]	rightsHandle   Specifies the pointer points a iterator of RO's information.
 *                            DRM library allocates a memory for a iterator.
 * @return	   This function returns DRM_RESULT_SUCCESS on success or other values on failure.
 * @remarks
 * @see 	      drm_svc_get_next_ro, drm_svc_close_ro_iterator, drm_svc_get_count_ro
 * @since          1.0
 */
DRM_RESULT drm_svc_open_ro_iterator(const char *filePath,
					    drm_rights_handle_t **rightsHandle);

/**
 * An application can get next RO's information from RO's Iterator.
 *
 *
 * @param[in]	rightsHandle	Specifies the pointer points a iterator of RO's information.
 * @param[out]	rightsInfo     Specifies the pointer points a RO's information.
 * @return		This function returns DRM_RESULT_SUCCESS on success or other values on failure.
 * @remarks
 * @see 	      drm_svc_open_ro_iterator, drm_svc_close_ro_iterator, drm_svc_get_count_ro
 * @since          1.0
 */
DRM_RESULT drm_svc_get_next_ro(drm_rights_handle_t *rightsHandle,
				       drm_rights_info_t *rightsInfo);

/**
 * An application can release resource for RO's Iterator.
 *
 * @param[in]	rightsHandle	Specifies the pointer points a iterator of RO's information.
 * @return		This function returns DRM_RESULT_SUCCESS on success or other values on failure.
 * @remarks
 * @see 	      drm_svc_open_ro_iterator, drm_svc_close_ro_iterator, drm_svc_get_count_ro
 * @since          1.0
 */
DRM_RESULT drm_svc_close_ro_iterator(drm_rights_handle_t **rightsHandle);

/**
 * An application can get count of RO from RO's Iterator.
 *
 * @param[in]	rightsHandle	Specifies the pointer points a iterator of RO's information.
 * @param[out]	count	         Specifies the pointer points a number of RO's information.
 * @return		This function returns DRM_RESULT_SUCCESS on success or other values on failure.
 * @remarks
 * @see 	      drm_svc_open_ro_iterator, drm_svc_get_next_ro, drm_svc_close_ro_iterator
 * @since          1.0
 */
DRM_RESULT drm_svc_get_count_ro(drm_rights_handle_t *rightsHandle,
					unsigned int *count);

/**
 * An application can remove all RO related with DRM file.
 *
 * @param[in]	pFilePath	   Specifies the pointer points a DRM file path.
 * @return		This function returns DRM_RESULT_SUCCESS on success or other values on failure.
 * @remarks
 * @see
 * @since          1.0
 */
DRM_RESULT drm_svc_remove_ro(const char *filePath);

/**
 * An application can remove all registered RO.
 *
 * @return		This function returns DRM_RESULT_SUCCESS on success or other values on failure.
 * @remarks
 * @see
 * @since          1.0
 */
DRM_RESULT drm_svc_remove_all_ro(void);

/**
 * An application can get a total number of registered RO.
 *
 * @param[out]	count	   Specifies the pointer points a total number of registered RO.
 * @return		This function returns DRM_RESULT_SUCCESS on success or other values on failure.
 * @remarks
 * @see
 * @since          1.0
 */
DRM_RESULT drm_svc_get_count_installed_ro(int *count);

/*---------------------------------------------------------------------------
						DRM ICON, UI, POPUP
---------------------------------------------------------------------------*/
/**
 * An application can get a highest priority RO for consuming .
 * This API should be used in DRMv1 contents.
 *
 * @param[in]	pFilePath	   Specifies the pointer points a DRM file path.
 * @param[in]	permType	      Enumeration type of permission.
 * @param[out] bestRights
 * @return		This function returns DRM_RESULT_SUCCESS on success or other values on failure.
 * @remarks: This API merges following constraints
			A. Count
			B. Timed-Count
			C. Accumulated
 * @see
 * @since          1.0
 */
DRM_RESULT drm_svc_get_best_merged_ro(const char *pFilePath,
					      DRM_PERMISSION_TYPE permType,
					      drm_best_rights_t *bestRights);

/**
 * An application can get a highest priority RO for consuming .
 *
 * @param[in]	pFilePath	   Specifies the pointer points a DRM file path.
 * @param[in]	permType	      Enumeration type of permission.
 * @param[out] bestRights
 * @return		This function returns DRM_RESULT_SUCCESS on success or other values on failure.
 * @remarks
 * @see
 * @since          1.0
 */
DRM_RESULT drm_svc_get_best_ro(const char *filePath,
				       DRM_PERMISSION_TYPE permType,
				       drm_best_rights_t *bestRights);

/*---------------------------------------------------------------------------
						DRM CONTENTS RENDERING
  ---------------------------------------------------------------------------*/

/**
 * An application can get a information of CEK by using content ID or group ID.
 *
 * @param[in]	cid	   Specifies the pointer points a content ID.
 * @param[in]	gid	   Specifies the pointer points a group ID.
 *                      If content has no group ID, this value should be NULL.
 * @param[out] keyinfo  Specifies the pointer points a information of CEK.
 * @return		This function returns DRM_RESULT_SUCCESS on success or other values on failure.
 * @remarks
 * @see 	      drm_svc_get_keyinfo_by_filepath
 * @since          1.0
 */
DRM_RESULT drm_svc_get_keyinfo_by_cid(char *cid,
					      char *gid,
					      drm_keyinfo_t *keyinfo);

/**
 * An application can get a information of CEK by using a DRM file path.
 *
 * @param[in]	pFilePath	Specifies the pointer points a DRM file path.
 * @param[out] keyinfo     Specifies the pointer points a information of CEK.
 * @return		This function returns DRM_RESULT_SUCCESS on success or other values on failure.
 * @remarks
 * @see 	      drm_svc_get_keyinfo_by_cid
 * @since          1.0
 */
DRM_RESULT drm_svc_get_keyinfo_by_filepath(const char *filePath,
						   drm_keyinfo_t *keyinfo);

/*---------------------------------------------------------------------------
								DRM STORAGE
---------------------------------------------------------------------------*/
/**
 * An application can register RO from a buffer contains RO data.
 * This API is designed for WAP PUSH.
 Uses Scenario

1.	DRM V1.0 rights
2.	DRM V2.0 protected RO
3.	DRM V2.0 1-pass RO response
4.	DRM V2.0 3-Pass RO Confirmation protocol
5.	DRM V2.1 WAP-PUSH ROAP trigger

 *
 * @param[in]	buffer	   Specifies the pointer points a buffer contains RO data.
 * @param[in]  size        The size of buffer.
 * @param[in]  version     Enumeration type of RO version.
 * @param[out]  cid     	content ID (For DRM V1 only).
 * @param[in]	pRoapNotiCB 	Specifies the pointer points a structure that composed callback functions(For DRM V2 only).
 * @param[in]	initiator      Application type running ROAP(For DRM V2 only).
 * @param[in]  appSessionData Specifies the pointer points a application's session data(For DRM V2 only).
*
 * @return		This function returns DRM_RESULT_SUCCESS on success or other values on failure.
 * @remarks-The following MIME types are  applicable for this API
	application/vnd.oma.drm.rights+xml
	application/vnd.oma.drm.rights+wbxml
	application/vnd.oma.drm.roap-trigger+wbxml
	application/vnd.oma.drm.roap-trigger+xml
	application/vnd.oma.drm.roap-pdu+xml
	application/vnd.oma.drm.ro+xml
 * @since          1.1
 */
DRM_RESULT drm_svc_register_ro(unsigned char *buffer, unsigned int size, DRM_RIGHTS_VERSION version, unsigned char **cid,	/*For DRM V1 only */
				       drm_roap_notification_cb_t *pRoapNotiCB,	/*For DRM V2 */
				       DRM_ROAP_INITIATOR initiator,	/*For DRM V2 */
				       drm_appsession_datatype_t *appSessionData	/*For DRM V2 */
	    );

/**
 * This API facilitates default DNET profile ID creation using browser profile. In other words, caller doesn't provide DNET profile info while using this API.
 * An application can register RO from a buffer contains RO data.
* This API is useful only for application which does not need ROAP processing notification(for example, ROAP user consent notification) like SMS WAP PUSH.  SMS WAP PUSH can ignore ROAP failure, because it doesn't have user interaction wihile ROAP.
 * This API aborts ROAP processing if FQDN is not present in default user-consent whitelist.
* For DRMV2, as part of ROAP activity,  HTTP processing may be needed after completion of this API. This processing is done silently(without application notification) by DRM engine .
* Since the application is used as host for silent DRM processing, so the application process should be alive(for example, daemon process) after completion of this API.

 * This API is designed primarily for WAP PUSH.

Uses Scenario
1.	DRM V1.0 rights
2.	DRM V2.0 protected RO
3.	DRM V2.0 1-pass RO response
4.	DRM V2.1 3-Pass RO Confirmation protocol
5.	DRM V2.1 WAP-PUSH ROAP trigger

 *
 * @param[in]	buffer	   Specifies the pointer points a buffer contains RO data.
 * @param[in]  size        The size of buffer.
 * @param[in]  version     Enumeration type of RO version.
 * @param[out]  cid     	content ID (For DRM V1 only).
 * @param[in]	initiator      Application type running ROAP.
 *
 * @return		This function returns DRM_RESULT_SUCCESS on success or other values on failure.
 * @remarks-	The following MIME types are  applicable for this API
	application/vnd.oma.drm.rights+xml
	application/vnd.oma.drm.rights+wbxml
	application/vnd.oma.drm.roap-trigger+wbxml
	application/vnd.oma.drm.roap-trigger+xml
	application/vnd.oma.drm.roap-pdu+xml
	application/vnd.oma.drm.ro+xml

 * @since          1.2
 */
DRM_RESULT drm_svc_register_ro_ex(unsigned char *buffer,	/* for Both */
					  unsigned int size,	/* for Both */
					  DRM_RIGHTS_VERSION version,	/* for Both */
					  unsigned char **cid,	/* for DRMv1 */
					  DRM_ROAP_INITIATOR initiator	/* for DRMv2 */
	    );

/**
* It is depreciated API and we suggest not to use this API.

 * An application can register RO from a file contains RO data.
 * This API is designed for WAP PUSH.
 * In OMA DRM v2.0, there is no user case for WAP PUSH.
 *
 * @param[in]	filePath	   Specifies the pointer points a RO file path.
 * @return		This function returns DRM_RESULT_SUCCESS on success or other values on failure.
 * @remarks
 * @see 	      drm_svc_register_ro
 * @since          1.0
 */
DRM_RESULT drm_svc_register_ro_file(const char *filePath);

/**
 * An application can register a DRM file when a DRM file is copied.
 * This function doesn't copy a DRM file physically, but only register destination DRM file.
 *
 * @param[in]	org	   Specifies the pointer points a source DRM file path.
 * @param[in]  dest     Specifies the pointer points a destination DRM file path.
 * @return		This function returns DRM_RESULT_SUCCESS on success or other values on failure.
 * @remarks
 * @see
 * @since          1.0
 */
DRM_RESULT drm_svc_register_copy_file(char *org, char *dest);

/**
 * An application can register a DRM file when a DRM file is moved.
 * This function doesn't move a DRM file physically, but only register destination DRM file and unregister source DRM file.
 *
 * @param[in]	org	   Specifies the pointer points a source DRM file path.
 * @param[in]  dest     Specifies the pointer points a destination DRM file path.
 * @return		This function returns DRM_RESULT_SUCCESS on success or other values on failure.
 * @remarks
 * @see
 * @since          1.0
 */
DRM_RESULT drm_svc_register_move_file(char *org, char *dest);

/**
 * An application can update directory name when directory name is changed.
 *
 * @param[in]	oldDir	Specifies the pointer points a old directory name.
 * @param[in]  newDir   Specifies the pointer points a new directory name.
 * @return		This function returns DRM_RESULT_SUCCESS on success or other values on failure.
 * @remarks
 * @see 	      drm_svc_open_ro_iterator, drm_svc_close_ro_iterator
 * @since          1.0
 */
DRM_RESULT drm_svc_update_dir_rename(char *oldDir, char *newDir);

/*---------------------------------------------------------------------------
								DRM TIME
---------------------------------------------------------------------------*/
/**
 * An application can set secure time.
 *
 * @param[in]	tm	   		Specifies the pointer points a secure time.
 * @param[in]   sourceType  The type of sercure time. Application use the value, DRM_TS_NITZ
 * @return		This function returns DRM_RESULT_SUCCESS on success or other values on failure.
 * @remarks
 * @see
 * @since          1.0
 */
DRM_RESULT drm_svc_set_secure_clock(struct tm *secureTime,
					    DRM_EM_TIME_SOURCE sourceType);

/**
 * An application can get secure time.
 *
 * @param[out] secureTime      Pointer to a tm structure which will be filled with Secure Time value.
 * @return  This function returns DRM_RESULT_SUCCESS on success or other values on failure.
 * @remarks
 * @see
 * @since          1.0
 */
DRM_RESULT drm_svc_get_secure_clock(struct tm *secureTime);

/**
 * An application can get a header information of a DRM file.
 *
 *
 * @param[in]	filePath	   Specifies the pointer points a DRM file path.
 * @param[out] headerInfo  Specifies the pointer points a header information of a DRM file.
 *                         Application should allocate a memory.
 * @return		This function returns DRM_RESULT_SUCCESS on success or other values on failure.
 * @remarks
 * @see
 * @since          1.0
 */
DRM_RESULT drm_svc_get_dcf_header_info(const char *filePath,
					       drm_dcf_header_t *headerInfo);
/**
 * An application can free a header information of a DRM file obtained using drm_svc_get_dcf_header_info().
 *
 *
 * @param[in] headerInfo  Specifies the pointer points a header information of a DRM file.
 *
 * @return		This function returns DRM_RESULT_SUCCESS on success or other values on failure.
 * @remarks
 * @see
 * @since          1.0
 */
DRM_RESULT drm_svc_free_dcf_header_info(drm_dcf_header_t *headerInfo);

/**
 * An application can get a number of MO(OMA DRM Container) in multipart-DCF.
 *
 * @param[in]	pFilePath	   Specifies the pointer points a DRM file path.
 * @param[out] count          Specifies the pointer points a number of OMA DRM Container.
 * @return		This function returns DRM_RESULT_SUCCESS on success or other values on failure.
 * @remarks
 * @see
 * @since          1.0
 */
DRM_RESULT drm_svc_get_dcf_mo_count(const char *filePath, int *count);

/**
 * An application can get a information of user data box specified in OMA-DRM-DCF.
 *
 * @param[in]	filePath	   Specifies the pointer points a DRM file path.
 * @param[in]  type        The sub-box type of user data box.
 * @parma[out] metadata    Specifies the pointer points a information of sub-box.
 * @return		This function returns DRM_RESULT_SUCCESS on success or other values on failure.
 * @remarks
 * @see 	      drm_svc_set_user_data_box_info, drm_svc_delete_user_data_box
 * @since          1.0
 */
DRM_RESULT drm_svc_get_user_data_box_info(const char *filePath,
						  DRM_METADATABOX_TYPE type,
						  drm_user_data_common_t *metadata);

/**
 * An application can set a information of user data box specified in OMA-DRM-DCF.
 *
 * @param[in]	filePath	   Specifies the pointer points a DRM file path.
 * @param[in]  type        The sub-box type of user data box.
 * @parma[in]  metadata    Specifies the pointer points a information of sub-box.
 *                         Application should allocate memory and filled parameter.
 * @return		This function returns DRM_RESULT_SUCCESS on success or other values on failure.
 * @remarks
 * @see 	      drm_svc_get_user_data_box_info, drm_svc_delete_user_data_box
 * @since          1.0
 */
DRM_RESULT drm_svc_set_user_data_box_info(const char *filePath,
						  DRM_METADATABOX_TYPE type,
						  drm_user_data_common_t *metadata);

/**
 * An application can delete a user data box of mutable box specified in OMA-DRM-DCF.
 *
 * @param[in]	filePath	   Specifies the pointer points a DRM file path.
 * @return		This function returns DRM_RESULT_SUCCESS on success or other values on failure.
 * @remarks
 * @see 	      drm_svc_get_user_data_box_info, drm_svc_set_user_data_box_info
 * @since          1.0
 */
DRM_RESULT drm_svc_delete_user_data_box(const char *filePath);

/**
 * An application can get a index of relative contents in a multipart-DCF.
 * For example, if the first MO in multipart-DCF has a preview field in header,
 *  the multipart-DCF may contain preview content.
 * In this case, this function returns the index of preview content in a multipart-DCF.
 *
 * @param[in]	pFilePath	   Specifies the pointer points a DRM file path.
 * @param[in]  type           Enumeration type of relative content.
 * @param[out] typeIndex      Specifies the pointer points a index of relative content in a multipart-DCF.
 * @return		This function returns DRM_RESULT_SUCCESS on success or other values on failure.
 * @remarks
 * @see
 * @since          1.0
 */
DRM_RESULT drm_svc_get_index_of_relative_contents(const char *filePath,
							  DRM_CONTENTS_INDEX_TYPE type, int *typeIndex);

/**
 * An application can get file path list by using content ID.
 * An application should call drm_svc_file_path_list_release to release resource of pathList.
 *
 * @param[in]	cid	      Specifies the pointer points a content ID.
 * @param[out] pathList    Specifies the pointer points a data contains file path list.
 * @return		This function returns DRM_RESULT_SUCCESS on success or other values on failure.
 * @remarks
 * @see 	      drm_svc_get_file_path_list_release
 * @since          1.0
 */
DRM_RESULT drm_svc_get_file_path_list_by_cid(char *cid,
						     drm_file_path_list_t *pathList);

/**
 * An application can release a resource of file path list.
 *
 * @param[in]	pathList	   Specifies the pointer points a data contains file path list.
 * @return		This function returns DRM_RESULT_SUCCESS on success or other values on failure.
 * @remarks
 * @see 	      drm_svc_get_file_path_list_by_cid
 * @since          1.0
 */
DRM_RESULT drm_svc_file_path_list_release(drm_file_path_list_t *pathList);

/**
 * An application can get RI URL in a DRM file.
 * An application can download RO by using RI URL.
 *
 * @param[in]	filePath	   Specifies the pointer points a DRM file path.
 * @param[out] url         Specifies the pointer points a RI URL.
 * @param[in]  size        The memory size that application allocate for url.
 * @return		This function returns DRM_RESULT_SUCCESS on success or other values on failure.
 * @remarks
 * @see
 * @since          1.0
 */
DRM_RESULT drm_svc_get_rights_url(const char *filePath,
					  char *url, unsigned int size);

/*************************************************************
This API will fetch the corresponding rights URL and initiates the rights acquisition process using DRM NET MANAGER.
1. To initiate Silent "in advance"
2. To initiate silent "On demand"
3. To initiate RO using embedded domain RO
5. To initiate Preview URL (Future implementation)

This API uses the Application defined callback to notify rights acquisition status.

**************************************************************/
DRM_RESULT drm_svc_go_rights_url(const char *const pFilePathWithContentIndex,
					 const DCF_EMBEDDED_ROURL_TYPE roURLType,
					 const drm_roap_notification_cb_t *const pRoapNotiCB,
					 drm_appsession_datatype_t *const appSessionData);

/**
 * An application can get Content URL in a DRM file.
 * An application can download Content by using Content URL.
 *
 * @param[in]   filePath    Specifies the pointer points a DRM file path.
 * @param[out]  url         Specifies the pointer points a Content URL.
 * @param[in]   size        The memory size that application allocate for url.
 * @return      This function returns DRM_RESULT_SUCCESS on success or other values on failure.
 * @remarks
 * @see
 * @since          1.0
 */
DRM_RESULT drm_svc_get_content_url(const char *filePath,
					   char *url, unsigned int size);

/**
 * An application can remove Content Cache in memory.
 * DRM core has a content information for performance.
 * If application uses a same temperary file for downloading a DRM contents,
 *  the information of DRM content may be invalid because of cache.
 * So, to acquire valid information, application should call this API.
 *
 * @param[in]   filePath    Specifies the pointer points a DRM file path.
 * @return      This function returns DRM_RESULT_SUCCESS on success or other values on failure.
 * @remarks
 * @see
 * @since          1.0
 */
DRM_RESULT drm_svc_remove_content_cache(const char *pFilePath);

/**
 * An application can get a handle for progressive download
 *
 * @param[in]   filePath    Specifies the pointer points a DRM file path.
 * @param[out]  pdHandle    Specifies the pointer points a handle for progressive download.
 * @return      This function returns DRM_RESULT_SUCCESS on success or other values on failure.
 * @remarks
 * @see
 * @since          1.0
 */
DRM_RESULT drm_svc_pd_open_file(char *filePath,
					DRM_PERMISSION_TYPE permType,
					DRM_PD_HANDLE *pdHandle);

/**
 * An application can get a status for progressive download or get a decrypted data.
 *
 * @param[in]   pdHandle   Specifies the pointer points a handle for progressive download.
 * @param[out]  pdOut      Specifies the pointer points a status of progressive download and DRM content.
 * @param[out]  buffer     Specifies the pointer points a decrypted data.
 * @param[out]  size       The size of buffer.
 * @param[out]  readSize   The size that DRM engine has read.
 * @return      This function returns DRM_RESULT_SUCCESS on success or other values on failure.
 * @remarks
 * @see
 * @since          1.0
 */
DRM_RESULT drm_svc_pd_read_file(DRM_PD_HANDLE pdHandle,
					drm_pd_output_t *pdOutput,
					unsigned char *buffer,
					unsigned int size,
					unsigned int *readSize);

/**
 * An application can move file pointer for DRM content.
 *
 * @param[in]   pdHandle    Specifies the pointer points a handle for progressive download.
 * @param[in]   offset      The offset value to move.
 * @param[in]   mode        The mode to decide start position.
 * @return      This function returns DRM_RESULT_SUCCESS on success or other values on failure.
 * @remarks
 * @see
 * @since          1.0
 */
DRM_RESULT drm_svc_pd_seek_file(DRM_PD_HANDLE pdHandle,
					int offset, DRM_FILE_SEEK_MODE mode);

/**
 * An application can get a file pointer for DRM content.
 *
 * @param[in]   pdHandle    Specifies the pointer points a handle for progressive download.
 * @param[out]  offset      A value of a file pointer.
 * @return      This function returns DRM_RESULT_SUCCESS on success or other values on failure.
 * @remarks
 * @see
 * @since          1.0
 */
DRM_RESULT drm_svc_pd_tell_file(DRM_PD_HANDLE pdHandle,
					unsigned int *offset);

/**
 * An application can notify a DRM engine to complete progressive downloading content.
 *
 * @param[in]   pdHandle    Specifies the pointer points a handle for progressive download.
 * @return      This function returns DRM_RESULT_SUCCESS on success or other values on failure.
 * @remarks
 * @see
 * @since          1.0
 */
DRM_RESULT drm_svc_pd_set_download_complete(DRM_PD_HANDLE pdHandle);

/**
 * An application can get Pregressive Download parse status info
 *
 * @param[in]   	filepath    			Complete path of the file
 * @param[in]   	bCurrDownloadSize    	Boolean value to indicate if the current download size is known.
 * @param[out]   	parseStatusInfo    		Structure which is filled with corresponding parameters
 * @return      This function returns DRM_RESULT_SUCCESS on success or other values on failure.
 * @remarks
 * @see
 * @since          1.0
 */
DRM_RESULT drm_svc_pd_get_parse_status_info(char *filepath,
						    DRM_BOOL bCurrDownloadSize,
						    drm_pd_parsing_status_t *parseStatusInfo);
/**
 * An application can release a handle for progressive download
 *
 * @param[in]   pdHandle    Specifies the pointer points a handle for progressive download.
 * @return      This function returns DRM_RESULT_SUCCESS on success or other values on failure.
 * @remarks
 * @see
 * @since          1.0
 */
DRM_RESULT drm_svc_pd_close_file(DRM_PD_HANDLE pdHandle);

/*---------------------------------------------------------------------------
							DRM CONTENT VERSION 1
---------------------------------------------------------------------------*/

/**
 * An application can prepare to convert a DRM file in OMADRM-v1.
 * If a type of DRM file is FL, CD or FL-SD type, application can convert to SD type.
 * This function prepare for converting and create file.
 *
 * @param[in]	filePath	   Specifies the pointer points a destination file path.
 *                         DRM library will write converted data to this file.
 * @param[in]  installRO   A boolean value whether register RO in a DRM file.
 *                         If a type of DRM file is CD and a original DRM file has been registered before,
 *                          this value must be DRM_FALSE for replay protection.
 * @param[out] hConvert    Specifies the pointer points a handle for converting.
 * @return		This function returns DRM_RESULT_SUCCESS on success or other values on failure.
 * @remarks
 * @see 	      drm_svc_write_convert, drm_svc_close_convert
 * @since          1.0
 */
DRM_RESULT drm_svc_open_convert(char *filePath,
					DRM_BOOL installRO,
					DRM_CONVERT_HANDLE *hConvert);

/**
 * An application can write converted data.
 *
 * @param[in]	hConvert	   A handle for converting.
 * @param[in]  buffer      Specifies the pointer points a buffer contains original data.
 * @param[in]  size        The size of buffer.
 * @param[out] written     The size of writing a destination file.
 * @return		This function returns DRM_RESULT_SUCCESS on success or other values on failure.
 * @remarks	   The size of buffer can differs from the size of writing a file.		  //spike
 * @see 	      drm_svc_open_convert, drm_svc_close_convert
 * @since          1.0
 */
DRM_RESULT drm_svc_write_convert(DRM_CONVERT_HANDLE hConvert,
					 unsigned char *buffer,
					 unsigned long size,
					 unsigned long *written);

/**
 * An application can release a resource for converting.
 *
 * @param[in]	hConvert	   A handle for converting.
 * @return		This function returns DRM_RESULT_SUCCESS on success or other values on failure.
 * @remarks
 * @see 	      drm_svc_open_convert, drm_svc_write_convert
 * @since          1.0
 */
DRM_RESULT drm_svc_close_convert(DRM_CONVERT_HANDLE hConvert);

/**
 * An application can check whether a DRM file is forward-locked.
 * A type of FL, CD and FL-SD is forward-locked in OMADRM-v1.
 * If a DRM file is forwart-locked, this function returns DRM_RESULT_SUCCESS.
 * This function check a original delivery method type of a converted DRM file.
 *
 * @param[in]	filePath	   Specifies the pointer points a DRM file path.
 * @return		This function returns DRM_RESULT_SUCCESS on success or other values on failure.
 * @remarks
 * @see 	      drm_svc_open_ro_iterator, drm_svc_close_ro_iterator
 * @since          1.0
 */
DRM_RESULT drm_svc_is_converted_fl(const char *filePath);

/*---------------------------------------------------------------------------
							DRM ENGINE & ETC
---------------------------------------------------------------------------*/
/**
 * An application can clear data include database.
 * This function clear informations, like a certification, contents, RO, RI and so on.
 *
 * @return		This function returns DRM_RESULT_SUCCESS on success or other values on failure.
 * @remarks
 * @see
 * @since          1.0
 */
DRM_RESULT drm_svc_reset_storage(void);

/*---------------------------------------------------------------------------
							DRM MMC
---------------------------------------------------------------------------*/

/**
 * An application should call this function when removable memory is inserted in target.
 * This function prepare to register content and RO in removable memory.
 *
 * @return		This function returns DRM_RESULT_SUCCESS on success or other values on failure.
 * @remarks
 * @see 	      drm_svc_open_ro_iterator, drm_svc_close_ro_iterator
 * @since          1.0
 */
DRM_RESULT drm_svc_insert_ext_memory(void);

/**
 * An application should call this function when removable memory is extracted in target.
 * This function unregister content and RO in removable memory.
 *
 * @return		This function returns DRM_RESULT_SUCCESS on success or other values on failure.
 * @remarks
 * @see 	      drm_svc_open_ro_iterator, drm_svc_close_ro_iterator
 * @since          1.0
 */
DRM_RESULT drm_svc_extract_ext_memory(void);

/*---------------------------------------------------------------------------
							For Linux
---------------------------------------------------------------------------*/

/**
 * An application can unregister DRM files when deletes directory.
 * This function will unregister DRM files in directory.
 *
 * @param[in]	dir	      Specifies the pointer points a directory name.
 * @param[in]  del_rights  A boolean value whether unregister RO.   //spike
 *                         If this value is DRM_TRUE, library will unregister RO, too.
 * @return		This function returns DRM_RESULT_SUCCESS on success or other values on failure.
 * @remarks
 * @see
 * @since          1.0
 */
DRM_RESULT drm_svc_delete_directory(char *dir, DRM_BOOL del_rights);

/**
 * An application can update registered DRM files when moves directory.
 * This function will update direcroty information of registered DRM file.
 *
 * @param[in]	srcDir	   Specifies the pointer points a source directory name.
 * @param[in]  destDir     Specifies the pointer points a destination directory name.
 * @return		This function returns DRM_RESULT_SUCCESS on success or other values on failure.
 * @remarks
 * @see
 * @since          1.0
 */
DRM_RESULT drm_svc_move_directory(char *srcDir, char *destDir);

/**
 * An application can register DRM files when copy directory.
 * This function will register copied DRM files.
 *
 * @param[in]	srcDir	   Specifies the pointer points a source directory name.
 * @param[in]  destDir     Specifies the pointer points a destination directory name.
 * @return		This function returns DRM_RESULT_SUCCESS on success or other values on failure.
 * @remarks
 * @see
 * @since          1.0
 */
DRM_RESULT drm_svc_copy_directory(char *srcDir, char *destDir);

/**
 * An application can make file path for another function.
 * If application wants to access a OMA DRM container in multipart-DCF, calls this function.
 * For example, application wants to get a best Rights of second OMA DRM container in multipart-DCF,
 *  call this function and submit fullPath value to parameter of the function, named "drm_svc_get_best_ro".
 *
 * @param[in]	filePath	      Specifies the pointer points a DRM file path.
 * @param[in]  index          Zero based index of OMA DRM container in multipart-DCF.
 * @param[in]  fullPathSize   The size of fullPath.
 *                            This value should be bigger than length of filePath.
 *                            Recommanded fullPathSize is length of filePath + 100.
 * @param[out] fullPath       File path that is made by DRM library.
 * @return		This function returns DRM_RESULT_SUCCESS on success or other values on failure.
 * @remarks
 * @see
 * @since          1.0
 */
DRM_BOOL drm_svc_make_multipart_drm_full_path(const char *filePath,
						      unsigned int index,
						      unsigned int fullPathSize,
						      char *fullPath);

/**
 * An application can make file path for another function.
 * OMA DRM file can be embedded in some file or message like a MMS.
 * An application can register a MMS file include DRM file.
 * If application wants to access a OMA DRM container in embedded and multipart-DCF, call this function.
 * For example, application wants to get a best Rights of second OMA DRM container in multipart-DCF,
 *  call this function and submit fullPath value to parameter of the function, named "drm_svc_get_best_ro".
 *
 * @param[in]	filePath	      Specifies the pointer points a DRM file path.
 * @param[in]  offset         The offset indicate the start position of a DRM file in a some file.
 * @param[in]  length         The length of DRM file.
 * @param[in]  index          Zero based index of OMA DRM container in multipart-DCF.
 * @param[in]  fullPathSize   The size of fullPath.
 *                            This value should be bigger than length of filePath.
 *                            Recommanded fullPathSize is length of filePath + 100.
 * @param[out] fullPath       File path that is made by DRM library.
 */
DRM_BOOL drm_svc_make_embedded_drm_full_path(const char *filePath,
						     unsigned int offset,
						     unsigned int length,
						     unsigned int index,
						     unsigned int fullPathSize,
						     char *fullPath);

/**
 * An application can get transaction ID value.
 * @param[in] char* 	pFilePath
 * @param[out] const drm_transaction_id_info_t*	trIDInfo
 * @return	DRM_RESULT
 * @remarks	 It extracts the transaction ID from ODF transaction box. This value is set in the structure namely trInfo
 *			 If transaction ID is not availble, then trIDInfo->trIDLen is zero.
 * @see		drm_svc_get_transaction_tracking, drm_svc_set_transaction_tracking
 * @since      	1.2
 */
DRM_RESULT drm_svc_get_transaction_id(char *const pFilePath,	/* IN */
					      drm_transaction_id_info_t *const trIDInfo);

/**
 * An application can set a setting value of transaction tracking.
 *
 * @param[in]	bTrackingOn    The value of transaction tracking.
 * @return		This function returns DRM_TRUE on success or other values on failure.
 * @remarks
 * @see 	      drm_svc_get_transaction_tracking
 * @since          1.0
 */
DRM_BOOL drm_svc_set_transaction_tracking(DRM_BOOL bTrackingOn);

/**
 * An application can get a setting value of transaction tracking.
 *
 * @param[out]	bTrackingOn    The value of transaction tracking.
 * @return		This function returns DRM_TRUE on success or other values on failure.
 * @remarks
 * @see 	      drm_svc_set_transaction_tracking
 * @since          1.0
 */
DRM_BOOL drm_svc_get_transaction_tracking(DRM_BOOL *bTrackingOn);

/**
 * An application can check whether a file can be SETAS or not.
 * Application that provide system constraint must call  drm_svc_set_app_system_constraint before calling this API.
 *
 * @param[in]		pFilePath    		File path.
 * @param[in]  	settingCategory     Setas Catagory.
 * @return		This function returns DRM_TRUE in case the file can be SETAS else it will return DRM_FALSE.
 * @remarks
 * @see 	      drm_svc_register_setas
 * @since          1.0
 */
DRM_BOOL drm_svc_has_valid_setas_status(char *pFilePath,
						DRM_SETAS_CATEGORY settingCategory);

/**
 * An application can register setting drm content for expiry reminder.
 *
 * @return		This function returns DRM_RESULT type.
 * @remarks
 * @see 	      drm_svc_unregister_setas
 * @since          1.0
 */
DRM_RESULT drm_svc_register_setas(char *pFilePath,
					  DRM_SETAS_CATEGORY settingCategory);

/**
 * An application can unregister setted drm content for expiry reminder.
 *
 * @return		This function returns DRM_RESULT type.
 * @remarks
 * @see 	      drm_svc_register_setas
 * @since          1.0
 */
DRM_RESULT drm_svc_unregister_setas(char *pFilePath,
					    DRM_SETAS_CATEGORY settingCategory);

/**
 * An application can get alarm infomation using alarm id
 * @param[out]	pAlarmData    Fills required information into this structure.
 * @return		This function returns DRM_BOOL type.
 * @remarks
 * @see
 * @since          1.0
 */
DRM_BOOL drm_svc_get_alarm_info(int alarm_id,
					drm_alarm_data_t *const pAlarmData);

/**
 * An application can initialize alarm for callback.
 *
 * @return		This function returns DRM_BOOL type.
 * @remarks
 * @see
 * @since          1.0
 */
DRM_BOOL drm_svc_init_alarm(void);

/**
 * An application can register callback to receive alarm.
 *
 *
 * @return		This function returns DRM_BOOL type.
 * @remarks		Same Callback is used for expiry reminder alarm and RUN alarm
 * @see
 * @since          1.0
 */
DRM_BOOL drm_svc_register_alarm_cb(drm_alarm_cb_t callback,
					   void *user_param);

/**
 * An application(launcher) can call this API after user select (yes/no) in the "expiry reminder pop-up".
 *
 * @param[in]		pFilePath	   		File path including the file name of the content whose expiry reminder need to be updated.
 * @param[in]  	tsettingCategory	SETAS Catagory for this content.
 * @param[in]  	texpiryType        	Expiry type received from application.
 * @param[out]  	showpopup        	bool value whether to show pop-up or not.
 * @return		This function returns DRM_RESULT enum based on various conditions.
 */
DRM_RESULT drm_svc_update_expiry_alarm(char *pFilePath,
					       DRM_SETAS_CATEGORY tsettingCategory,
					       DRM_DB_EXPIRY_TYPE texpiryType,
					       DRM_BOOL *showpopup);

/**
 * An application can call this API to set the system constraint.
 *
 * @param[in]		pApp_info	   		System constraint relation information to be set.
 * @return		This function returns DRM_RESULT_SUCCESS on success or error enum on failure.
 */
DRM_RESULT drm_svc_set_app_system_constraint(const drm_app_constraint_info *const pApp_info);

/**
 * An application can call this API to get the system constraint.
 *
 * @param[in]		type	   		Constraint type to be supplied by the Calling API.
 * @param[out]  	p_app_info	System constraint relation information will be filled by this API.
 * @return		This function returns DRM_RESULT_SUCCESS on success or error enum on failure.
 */
DRM_RESULT drm_svc_get_app_system_constraint(DRM_APP_SYS_CONSTRAINT_TYPE type,
						     drm_app_constraint_info *p_app_info);

/**
 * An application can call this API to delete system constraint set by it earlier.
 * @return		This function returns DRM_RESULT_SUCCESS on success or error enum on failure.
 */
DRM_RESULT drm_svc_delete_app_system_constraint(void);

/**
 * Launcher can create or update RUN (Rights Update Notification) alarm.
 * This API should be called when launcher receive event DRM_NOTI_ID_UPDATE_RUN_ALARM.
 * In the case of RUN alarm expiry also,this API should be called to update alarm.
 *
 * @param[in]		RoID	    	Specifies the Rights Object ID.
 * @return		This function returns DRM_RESULT_SUCCESS on success or other values on failure.
 */
DRM_RESULT drm_svc_update_create_run_alarm(unsigned int RoID);

/**
 * Launcher can delete RO corresponding to AlarmID.
 * This API should be called when launcher receives Alarm expiry calllback.
 *
 * @param[in]		gconf_run_expiry_time	    	Specifies the RUN Alarm Expiry time.
 * @return		This function returns DRM_RESULT_SUCCESS on success or other values on failure.
 */
DRM_RESULT drm_svc_handle_run_alarm_expiry(unsigned long gconf_run_expiry_time);

/**
 * An application can get Content ID list by using Rights Object ID.
 * An application should call drm_svc_cid_list_release to release resource of CID list.
 *
 * @param[in]		RoID	      	Specifies the RO ID.
 * @param[out] 	CidList    		Specifies the pointer points a data contains CID list.
 * @return		This function returns DRM_RESULT_SUCCESS on success or other values on failure.
 * @see 	      		drm_svc_cid_list_release, drm_svc_get_file_path_list_by_cid
 */
DRM_RESULT drm_svc_get_cid_list_by_roid(unsigned int RoID,
						drm_cid_list_t *CidList);

/**
 * An application can release a resource of CID list.
 *
 * @param[in]		CidList	   Specifies the pointer points to a data containing CID list.
 * @return		This function returns DRM_RESULT_SUCCESS on success or other values on failure.
 * @see 	      		drm_svc_get_cid_list_by_roid
 */
DRM_RESULT drm_svc_cid_list_release(drm_cid_list_t *CidList);

/*===========================================================================

							DIVXDRM service layer API

===========================================================================*/


DRM_BOOL drm_svc_divx_is_divx_drm_file(const char *filepath);

/**
 *  An application can get registration code( device specific )
 *
 * @param[out]buffer	Specifies the pointer points a buffer for getting registration code.
 * @param[out] size	size of buffer
 * @return		This function returns DRM_TRUE on success or DRM_FALSE on failure.
 * @remarks
 * @see 	      drm_svc_divx_get_deregistration_code, drm_svc_divx_is_device_activated
 * @since          1.0
 */
DRM_BOOL drm_svc_divx_get_registration_code(char *registrationCodeString,
						    int *codeLength);

/**
 *  An application can check whether device is registered or not.
 *
 * @param[out] flag	if registered, return TRUE.
 * @return		This function returns DRM_TRUE on success or DRM_FALSE on failure.
 * @remarks
 * @see 	      drm_svc_divx_get_registration_code, drm_svc_divx_is_device_activated
 * @since          1.0
 */
DRM_BOOL drm_svc_divx_is_device_activated(int *is_first);

/**
 *  An application can get deregistration code( device specific )
 *
 * @param[out]buffer	Specifies the pointer points a buffer for getting deregistration code.
 * @param[out] size	size of buffer
 * @return		This function returns DRM_TRUE on success or DRM_FALSE on failure.
 * @remarks  if this api is called. DivX DRM memory is reset, and return deregistration code to input DivX Provider site.
 * @see 	      drm_svc_divx_get_registration_code, drm_svc_divx_is_device_activated
 * @since          1.0
 */
DRM_BOOL drm_svc_divx_get_deregistration_code(char *deactivationCodeString,
						      int *codeLength);

/**
 *  An application should call This api for consuming DivX DRM contents.
 *
 * @param[in] handle 	 Handle that identifies DRM file.
 * @return		This function returns DRM_TRUE on success or DRM_FALSE on failure.
 * @remarks  This api should be called between drm_svc_open_file and drm_svc_read_file
 * @see 	     drm_svc_open_file,  drm_svc_read_file
 * @since          1.0
 */
DRM_RESULT drm_svc_divx_commit_playback(DRM_FILE_HANDLE hfile);

/**
 *  An application can get DivX content Infomation(Rights specific)
 *
 * @param[in] FilePath	Specifies the pointer points a DRM file path.
 * @param[out] pcontent	Specifies the pointer points DivX Structure.
 * @return	This function returns DRM_TRUE on success or DRM_FALSE on failure.
 * @remarks
 * @see
 * @since          1.0
 */
DRM_RESULT drm_svc_divx_get_right(const char *filepath,
					  drmContentInfo_t *content);

/*===========================================================================

							PlayReady service layer API

===========================================================================*/

/**
 * [PlayReady-specific API] This function returns the License info of the PR Content specified in the filepath
 *
 * @param[in]  filePath	      	Complete file path of the PR Content
 * @return				This function returns license information of drm_wm_content_right_info* type on success or NULL on failure.
 * @remarks
 * @see 	      				drm_svc_pr_free_license_info
 * @since         			1.0
 */
drm_wm_content_right_info *drm_svc_pr_get_license_info(const char *filePath);

/**
 * [PlayReady-specific API] This function returns current status indicating whether secure time is set or not.
 *
 * @return		This function returns DRM_TRUE if Secure Clock is set or DRM_FALSE.
 * @remarks
 * @see
 * @since         	 1.0
 */
DRM_BOOL drm_svc_pr_is_valid_secure_clock(void);

/**
*[Playready-specific API] This function is used to send Initiator request to the server and is called from the browser.
 *
 * @param[in]  		initiatorUrl	      	Pointer to the url of the Initiator for a particular media content. This can be initiator for Join Domain, Leave Domain, Metering, License Acquisition etc.
 * @param[in/out]  	DrmPRespdata	Pointer to drm_pr_response_data.It contains contentUrl & server error code if any, function pointer to hold the operation callback
 *									[in]Application can register callback for PR operations.
 *									[out]Content URL if present and Server response code will be sent out to application.
 * @return		This function returns DRM_TRUE on success, or DRM_FALSE on failure.
 * @remarks 		DrmPRespdata contains ContentUrl that will point to the content on the server and has to be then downloaded if content url is NOT NULL
 * @remarks 		DrmPRespdata contains Server error code.Application should check the error code & take proper action like showing popup to user etc.
 * @remarks 		DrmPRespdata contains function pointer for PR operation Callback. Application can register the callback for showing popup etc.
 * @see
*/
DRM_BOOL drm_svc_pr_submit_initiator_url(char *initiatorUrl,
						 drm_pr_response_data *DrmPRespdata);

/**
* [Playready-specific API] This function is used to free the license information retrieved for the content.
 *
 * @param[in]  right	Pointer to the url of the Rights for a particular media content.
 * @return	This function returns void.
 * @remarks memory is allocated in drm_svc_pr_get_license_info
 * @see drm_svc_pr_get_license_info
*/
void drm_svc_pr_free_license_info(drm_wm_content_right_info **right);

/**
 * [Playready-specific API]
 * An application can get PlayReady handle that is used for reading decrypted data.
 *
 * @param[in]		filePath	   		Specifies the pointer points a PlayReady file path.
 * @param[in]  	permType    		Enumeration type of permission.
 * @param[out] 	handlePr       		Handle that identifies PlayReady file.
 * @param[in/out]	 DrmPRespdata	 Pointer to drm_pr_response_data.It contains contentUrl & server error code if any, function pointer to hold the operation callback
 * 								 [in]Application can register callback for PR operations.
 * 								 [out]Content URL if present and Server response code will be sent out to application.
 * @return		This function returns DRM_RESULT_SUCCESS on success or other values on failure.
 * @remarks 	 	DrmPRespdata contains ContentUrl that will point to the content on the server and has to be then downloaded if content url is NOT NULL
 * @remarks		DrmPRespdata contains Server error code.Application should check the error code & take proper action like showing popup to user etc.
 * @remarks		DrmPRespdata contains function pointer for PR operation Callback. Application can register the callback for showing popup etc.
 * @see
 * @since          1.0
 */
DRM_RESULT drm_svc_pr_decrypt_init(const char *filePath,
					   DRM_PERMISSION_TYPE permType,
					   DRM_PLAYREADY_APP_HANDLE *handlePr,
					   drm_pr_response_data *DrmPRespData);

/**
 * [Playready-specific API]
 * An application can bind to a particular license & update it.
 *
 * @param[in]		handlePr	      Handle that identifies PlayReady file recevied from drm_svc_pr_decrypt_init.
 *
 * @return		This function returns DRM_RESULT_SUCCESS on success or other values on failure.
 * @remarks		This API must be called before drm_svc_pr_decrypt_payload
 * @see 	      		drm_svc_pr_decrypt_init,drm_svc_pr_decrypt_payload,drm_svc_pr_decrypt_deinit
 * @since          	1.0
 */
DRM_RESULT drm_svc_pr_bind_commit(DRM_PLAYREADY_APP_HANDLE handlePr);

/**
 * [Playready-specific API]
 * An application can read the decrypted data from PlayReady and WMDRM files.
 *
 * @param[in]			handlePr	      			Handle that identifies PlayReady file.
 * @param[in][out]		PayloadData	      		[in]	 Pointer to Encrypted Payload Data .
										[out] Pointer to Decrypted Payload Data.
 * @param[in]			PayloadDataSize	      	Size of Payload Data.
 * @param[in]  		ReplicatedData      	Pointer to Replicated data.
 * @param[in]  		ReplicatedDataLength   Length of replicated data.
 * @param[in] 		OffsetIntoMediaObject 	Byte offset in the media object this data payload belongs to.
 *
 * @return			Returns DRM_RESULT_SUCCESS on success or other values on failure.
 * @remarks			drm_svc_pr_decrypt_init must be called before calling this API
 * @see 	      			drm_svc_pr_decrypt_init,drm_svc_pr_decrypt_deinit
 *
 */
DRM_RESULT drm_svc_pr_decrypt_payload(DRM_PLAYREADY_APP_HANDLE handlePr,
					      unsigned char *PayloadData,
					      unsigned int PayloadDataSize,
					      unsigned char *ReplicatedData,
					      unsigned int ReplicatedDataLength,
					      unsigned int OffsetIntoMediaObject);

/**
 * [Playready-specific API]
 * An application can de-initialize PlayReady handle & release all relevant resources.
 *
 * @param[in]		*handlePr	      pointer to handle that identifies PlayReady file recevied from drm_svc_pr_decrypt_init.
 *
 * @return		This function returns DRM_RESULT_SUCCESS on success or other values on failure.
 * @remarks
 * @see 	      		drm_svc_pr_decrypt_init
 * @since          	1.0
 */
DRM_RESULT drm_svc_pr_decrypt_deinit(DRM_PLAYREADY_APP_HANDLE *handlePr);

/**
 * [Playready-specific API]
 * An application can delete all licenses specific to PlayReady, WMDRM & PIFF.
 *
 * @return		This function returns DRM_RESULT_SUCCESS on success or other values on failure.
 * @remarks
 * @since          	1.0
 */
DRM_RESULT drm_svc_pr_delete_all_licenses(void);

/**
 * [Playready-specific API]
 * An application can check if a PlayReady content can be copied.
 *
 * @param[in]		SrcFile	PlayReady content that need to be copied.
 * @param[in]		CopyTo	Destination enum (copy to another device / burn to CD / copy to PC)
 *
 * @return		This function returns DRM_TRUE if copy is allowed and DRM_FALSE if copy is not allowed.
 * @remarks
 * @since          	1.0
 */
DRM_BOOL drm_svc_pr_is_copy_allowed(const char *SrcFile, DRM_PR_COPY_OPERATION CopyTo);

/**
 * [Playready-specific API]
 * An application can notify the status of the copy operation for the PlayReady content
 *
 * @param[in]		SrcFile			PlayReady content that was used to copy.
 * @param[in]		copy_status		Status of Copy operation if it was SUCCESSFUL/UNSUCCESSFUL.
 *
 * @return		This function returns DRM_RESULT_SUCCESS on Success else appropriate error code is returned
 * @remarks		This is needed to update the Copy Count license only after successful copy operation
 * @since          	1.0
 */
DRM_RESULT drm_svc_pr_copy_status(const char *SrcFile, DRM_PR_COPY_STATUS copy_status);

/**
 * [PIFF-Smooth Streaming-specific API]
 * An application can get license for PIFF contents.
 *
 * @param[in]			lic_header_info	pointer to lic_header_info. Application MUST fill the members with PIFF DRM header information.
 * @param[in/out]		piff_lic_response	Pointer to drm_pr_response_data.It contains contentUrl (not applicable in this case)
 *									& server error code if any, function pointer to hold the operation callback.
 * 								 	[in]Application can register callback for license events.
 * 								 	[out]Server response code will be sent out to application.
 *
 * @return		This function returns DRM_RESULT_SUCCESS on success or other values on failure.
 * @remarks		Application should manage (allocate & free) memories to the pointers.
 * @since          	1.0
 */
 DRM_RESULT drm_svc_piff_get_license(drm_piff_header_info *lic_header_info,
										 drm_pr_response_data *piff_lic_response);


/**
 * [PIFF-Smooth Streaming-specific API]
 * An application can get PIFF handle that is used for reading decrypted payload.
 *
 * @param[in]		lic_header_info	pointer to lic_header_info. Application MUST fill the members with PIFF DRM header information.
 * @param[in]  	permType    		Enumeration type of permission.
 * @param[out] 	handlePiff       	Handle that identifies PIFF content.
 * @param[in/out]	piff_lic_response	Pointer to drm_pr_response_data.It contains contentUrl (not applicable in this case)
 * 								& server error code if any, function pointer to hold the operation callback.
 * 								[in]Application can register callback for license events.
 * 								[out]Server response code will be sent out to application.
 *
 * @return		This function returns DRM_RESULT_SUCCESS on success or other values on failure.
 * @remarks		piff_lic_response contains Server error code.Application should check the error code & take proper action like showing popup to user etc.
 * @remarks		piff_lic_response contains function pointer for license operation Callback. Application can register the callback for showing popup etc.
 * @see
 * @since          1.0
 */
DRM_RESULT drm_svc_piff_decrypt_init(drm_piff_header_info *lic_header_info,
					   DRM_PERMISSION_TYPE permType,
					   DRM_PIFF_APP_HANDLE *handlePiff,
					   drm_pr_response_data *piff_lic_response);

/**
 * [PIFF-Smooth Streaming-specific API]
 * An application can bind to a particular license & update it.
 *
 * @param[in]		handlePiff	      Handle that identifies PIFF content recevied from drm_svc_piff_decrypt_init.
 *
 * @return		This function returns DRM_RESULT_SUCCESS on success or other values on failure.
 * @remarks		This API must be called before drm_svc_piff_decrypt_payload
 * @see 	      		drm_svc_piff_decrypt_init,drm_svc_piff_decrypt_payload,drm_svc_piff_decrypt_deinit
 * @since          	1.0
 */
DRM_RESULT drm_svc_piff_bind_commit(DRM_PIFF_APP_HANDLE handlePiff);

/**
 * [PIFF-Smooth Streaming-specific API]
 * An application can get the decrypted payload from PIFF encrypted payload.
 *
 * @param[in]			handlePiff			Handle that identifies PIFF content.
 * @param[in/out]		payload_info	      		Pointer to drm_piff_payload_info.
 										[in]	 payload_data:Pointer to Encrypted Payload.
 										[in]	 payload_data_len:Length of Encrypted Payload.
 										[in]	 payload_iv:Pointer to IV of Encrypted Payload.
 										[in]	 payload_iv_len:Length of IV of Encrypted Payload.
										[out] payload_data:Pointer to Decrypted Payload.
 *
 * @return			Returns DRM_RESULT_SUCCESS on success or other values on failure.
 * @remarks			drm_svc_piff_decrypt_init must be called before calling this API
 * @see 	      			drm_svc_piff_decrypt_init,drm_svc_piff_decrypt_deinit
 * @since          	1.0
 */
DRM_RESULT drm_svc_piff_decrypt_payload(DRM_PIFF_APP_HANDLE handlePiff,
						drm_piff_payload_info *payload_info);

/**
 * [PIFF-Smooth Streaming-specific API]
 * An application can de-initialize PIFF handle & release all relevant resources.
 *
 * @param[in]		handlePiff	pointer to handle that identifies PIFF content recevied from drm_svc_piff_decrypt_init.
 *
 * @return		This function returns DRM_RESULT_SUCCESS on success or other values on failure.
 * @remarks
 * @see 	      		drm_svc_piff_decrypt_init
 * @since          	1.0
 */
DRM_RESULT drm_svc_piff_decrypt_deinit(DRM_PIFF_APP_HANDLE *handlePiff);

/**
	*@}
*//* Doxygen : addtogroup */

#ifdef __cplusplus
}
#endif
#endif/*__DRM_SERVICE_H__*/
